==> moonlight-1.20-2.16.14-fabric-sources.jar: net/mehvahdjukaar/moonlight/core/mixins/ItemInHandRendererMixin.java <==
package net.mehvahdjukaar.moonlight.core.mixins;

import com.llamalad7.mixinextras.sugar.Local;
import net.mehvahdjukaar.moonlight.api.item.IFirstPersonAnimationProvider;
import net.mehvahdjukaar.moonlight.api.item.IFirstPersonSpecialItemRenderer;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1799;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_742;
import net.minecraft.class_759;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_759.class)
public abstract class ItemInHandRendererMixin {

    @Inject(method = "renderArmWithItem", at = @At(value = "INVOKE",
            ordinal = 1,
            target = "Lnet/minecraft/client/renderer/ItemInHandRenderer;renderItem(Lnet/minecraft/world/entity/LivingEntity;Lnet/minecraft/world/item/ItemStack;Lnet/minecraft/world/item/ItemDisplayContext;ZLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V"),
            require = 1)
    public void moonlight$animateItem(class_742 player, float partialTicks, float pitch,
                                      class_1268 hand, float swingProgress, class_1799 stack,
                                      float handHeight, class_4587 poseStack, class_4597 buffer,
                                      int combinedLight, CallbackInfo ci) {
        IFirstPersonAnimationProvider provider = IFirstPersonAnimationProvider.get(stack.method_7909());
        if (provider != null) {
            boolean mainHanded = hand == class_1268.field_5808;
            class_1306 arm = mainHanded ? player.method_6068() : player.method_6068().method_5928();
            provider.animateItemFirstPerson(player, stack, hand, arm, poseStack, partialTicks, pitch, swingProgress, handHeight);
        }
    }

    @Inject(method = "renderArmWithItem", at = @At(value = "INVOKE",
            target = "Lnet/minecraft/client/player/AbstractClientPlayer;isUsingItem()Z",
            ordinal = 1,
            shift = At.Shift.BEFORE), cancellable = true)
    public void moonlight$renderSpecial(class_742 player, float partialTicks, float pitch, class_1268 hand,
                                        float swingProgress, class_1799 stack, float equippedProgress,
                                        class_4587 poseStack, class_4597 buffer, int combinedLight, CallbackInfo ci,
                                        @Local class_1306 arm) {
        IFirstPersonSpecialItemRenderer provider = IFirstPersonSpecialItemRenderer.get(stack.method_7909());
        if (provider != null) {
            if (provider.renderFirstPersonItem(player, stack,hand, arm, poseStack, partialTicks, pitch, swingProgress, equippedProgress,
                    buffer, combinedLight, (class_759) (Object) this)) {
                poseStack.method_22909();
                ci.cancel();
            }
        }
    }

}

==> moonlight-1.21-2.25.0-fabric-sources.jar: net/mehvahdjukaar/moonlight/core/mixins/ItemInHandRendererMixin.java <==
package net.mehvahdjukaar.moonlight.core.mixins;

import com.llamalad7.mixinextras.sugar.Local;
import net.mehvahdjukaar.moonlight.api.item.IFirstPersonAnimationProvider;
import net.mehvahdjukaar.moonlight.api.item.IFirstPersonSpecialItemRenderer;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1799;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_742;
import net.minecraft.class_759;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_759.class)
public abstract class ItemInHandRendererMixin {

    @Inject(method = "renderArmWithItem", at = @At(value = "INVOKE",
            ordinal = 1,
            target = "Lnet/minecraft/client/renderer/ItemInHandRenderer;renderItem(Lnet/minecraft/world/entity/LivingEntity;Lnet/minecraft/world/item/ItemStack;Lnet/minecraft/world/item/ItemDisplayContext;ZLcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V")
    )
    public void moonlight$animateItem(class_742 player, float partialTicks, float pitch,
                                      class_1268 hand, float swingProgress, class_1799 stack,
                                      float handHeight, class_4587 poseStack, class_4597 buffer,
                                      int combinedLight, CallbackInfo ci) {
        IFirstPersonAnimationProvider provider = IFirstPersonAnimationProvider.get(stack.method_7909());
        if (provider != null) {
            boolean mainHanded = hand == class_1268.field_5808;
            class_1306 arm = mainHanded ? player.method_6068() : player.method_6068().method_5928();
            provider.animateItemFirstPerson(player, stack, hand, arm, poseStack, partialTicks, pitch, swingProgress, handHeight);
        }
    }

    @Inject(method = "renderArmWithItem", at = @At(value = "INVOKE",
            target = "Lnet/minecraft/client/player/AbstractClientPlayer;isUsingItem()Z",
            ordinal = 1,
            shift = At.Shift.BEFORE), cancellable = true)
    public void moonlight$renderSpecial(class_742 player, float partialTicks, float pitch, class_1268 hand,
                                        float swingProgress, class_1799 stack, float equippedProgress,
                                        class_4587 poseStack, class_4597 buffer, int combinedLight, CallbackInfo ci,
                                        @Local class_1306 arm) {
        IFirstPersonSpecialItemRenderer provider = IFirstPersonSpecialItemRenderer.get(stack.method_7909());
        if (provider != null) {
            if (provider.renderFirstPersonItem(player, stack,hand, arm, poseStack, partialTicks, pitch, swingProgress, equippedProgress,
                    buffer, combinedLight, (class_759) (Object) this)) {
                poseStack.method_22909();
                ci.cancel();
            }
        }
    }

}
